"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _getOptionLabel = _interopRequireDefault(require("./getOptionLabel"));

var _getStringLabelKey = _interopRequireDefault(require("./getStringLabelKey"));

var labelKeyFn = function labelKeyFn(o) {
  return o.name;
};

describe('getOptionLabel', function () {
  var name, option;
  beforeEach(function () {
    name = 'California';
    option = {
      name: name
    };
  });
  it('returns a string when it receives a string `option` value', function () {
    var optionLabel = (0, _getOptionLabel["default"])(name, '');
    expect(optionLabel).toBe(name);
  });
  it('returns a string when it receives a `labelKey` function', function () {
    var optionLabel = (0, _getOptionLabel["default"])(option, labelKeyFn);
    expect(optionLabel).toBe(name);
  });
  it('returns a string when it receives a `labelKey` string', function () {
    var optionLabel = (0, _getOptionLabel["default"])(option, 'name');
    expect(optionLabel).toBe(name);
  });
  it('handles custom and pagination options', function () {
    var _customOption, _paginationOption;

    var customOption = (_customOption = {}, (0, _defineProperty2["default"])(_customOption, (0, _getStringLabelKey["default"])(labelKeyFn), 'foo'), (0, _defineProperty2["default"])(_customOption, "customOption", true), _customOption);
    var paginationOption = (_paginationOption = {}, (0, _defineProperty2["default"])(_paginationOption, (0, _getStringLabelKey["default"])(labelKeyFn), 'bar'), (0, _defineProperty2["default"])(_paginationOption, "paginationOption", true), _paginationOption);
    expect((0, _getOptionLabel["default"])(customOption, labelKeyFn)).toBe('foo');
    expect((0, _getOptionLabel["default"])(paginationOption, labelKeyFn)).toBe('bar');
  });
  it('gives precedence to `labelKey` when it is a function', function () {
    var customLabel = 'Custom Label';
    var optionLabel = (0, _getOptionLabel["default"])(name, function () {
      return customLabel;
    });
    expect(optionLabel).toBe(customLabel);
  });
  it('throws an error when an invalid option is encountered', function () {
    var willThrow = function willThrow() {
      return (0, _getOptionLabel["default"])([], 'name');
    };

    expect(willThrow).toThrowError(Error);
  });
  it('throws an error when `option` is an object and no labelkey is specified', function () {
    var willThrow = function willThrow() {
      return (0, _getOptionLabel["default"])(option);
    };

    expect(willThrow).toThrowError(Error);
  });
});