import React from 'react';
import * as stories from './ClearButton.stories';
import { composeStories, fireEvent, generateSnapshots, render, screen, userEvent } from '../../tests/helpers';

var _composeStories = composeStories(stories),
    Default = _composeStories.Default,
    Large = _composeStories.Large;

describe('<ClearButton>', function () {
  generateSnapshots(stories);
  it('renders a default clear button', function () {
    render( /*#__PURE__*/React.createElement(Default, null));
    expect(screen.getByRole('button').className).toBe('close btn-close rbt-close');
  });
  it('renders a large clear button', function () {
    render( /*#__PURE__*/React.createElement(Large, null));
    expect(screen.getByRole('button').className).toContain('rbt-close-lg');
  });
  it('registers a click', function () {
    var onClick = jest.fn();
    render( /*#__PURE__*/React.createElement(Default, {
      onClick: onClick
    }));
    var button = screen.getByRole('button');
    userEvent.click(button);
    expect(onClick).toHaveBeenCalledTimes(1);
  });
  it('prevents the default backspace behavior', function () {
    var onKeyDown = jest.fn();
    var isDefault;
    render( /*#__PURE__*/React.createElement(Default, {
      onKeyDown: onKeyDown
    }));
    var button = screen.getByRole('button');
    isDefault = fireEvent.keyDown(button, {
      key: 'Backspace'
    });
    expect(onKeyDown).toHaveBeenCalledTimes(1);
    expect(isDefault).toBe(false);
    isDefault = fireEvent.keyDown(button, {
      key: 'Enter'
    });
    expect(onKeyDown).toHaveBeenCalledTimes(2);
    expect(isDefault).toBe(true);
  });
});