import React from 'react';
import Highlighter from './Highlighter';
import { render } from '../../tests/helpers';

function getMatches(nodes) {
  var arr = Array.from(nodes);
  return arr.filter(function (node) {
    return node.tagName === 'MARK';
  });
}

describe('<Highlighter>', function () {
  it('does not highlight text when there is no search string', function () {
    var _render = render( /*#__PURE__*/React.createElement(Highlighter, {
      search: ""
    }, "California")),
        container = _render.container;

    var nodes = container.childNodes;
    expect(nodes).toHaveLength(1);
    expect(nodes.item(0)).toHaveTextContent('California');
    expect(getMatches(nodes)).toHaveLength(0);
  });
  it('does not highlight text when there is no match', function () {
    var _render2 = render( /*#__PURE__*/React.createElement(Highlighter, {
      search: "x"
    }, "California")),
        container = _render2.container;

    expect(getMatches(container.childNodes)).toHaveLength(0);
  });
  it('handles an empty child string', function () {
    // Explicitly set a string as the child.
    // eslint-disable-next-line react/jsx-curly-brace-presence
    var _render3 = render( /*#__PURE__*/React.createElement(Highlighter, {
      search: "foo"
    }, '')),
        container = _render3.container;

    expect(container.childNodes.item(0)).toHaveTextContent('');
  });
  it('highlights text within a string', function () {
    var _render4 = render( /*#__PURE__*/React.createElement(Highlighter, {
      search: "i"
    }, "California")),
        container = _render4.container;

    var nodes = container.childNodes;
    var matches = getMatches(nodes); // Output: [Cal, <mark>i</mark>, forn, <mark>i</mark>, a]

    expect(nodes.length).toBe(5);
    expect(nodes.item(0)).toHaveTextContent('Cal');
    expect(matches.length).toBe(2);
    expect(matches[0]).toHaveTextContent('i');
    expect(matches[0]).toHaveClass('rbt-highlight-text');
  });
  it('highlights text at the beginning of a string', function () {
    var _render5 = render( /*#__PURE__*/React.createElement(Highlighter, {
      search: "cal"
    }, "California")),
        container = _render5.container;

    var nodes = container.childNodes;
    var matches = getMatches(nodes); // Output: [<mark>Cal</mark>, ifornia]

    expect(nodes).toHaveLength(2);
    expect(nodes.item(0)).toHaveTextContent('Cal');
    expect(matches).toHaveLength(1);
    expect(matches[0]).toHaveTextContent('Cal');
  });
  it('adds custom classnames to the highlighted children', function () {
    var _render6 = render( /*#__PURE__*/React.createElement(Highlighter, {
      highlightClassName: "foo",
      search: "i"
    }, "California")),
        container = _render6.container;

    expect(getMatches(container.childNodes)[0]).toHaveClass('foo');
  });
});