import React from 'react';
import * as stories from './TypeaheadMenu.stories';
import { composeStories, generateSnapshots, render, screen } from '../../tests/helpers';

var _composeStories = composeStories(stories),
    CustomChildren = _composeStories.CustomChildren,
    CustomOption = _composeStories.CustomOption,
    Pagination = _composeStories.Pagination;

describe('<TypeaheadMenu>', function () {
  generateSnapshots(stories);
  it('renders a custom option', function () {
    render( /*#__PURE__*/React.createElement(CustomOption, null));
    expect(screen.getByRole('option')).toHaveTextContent('New selection:');
  });
  it('renders custom new selection text', function () {
    render( /*#__PURE__*/React.createElement(CustomOption, {
      newSelectionPrefix: "Select new: "
    }));
    expect(screen.getByRole('option')).toHaveTextContent('Select new:');
  });
  it('renders a pagination item', function () {
    render( /*#__PURE__*/React.createElement(Pagination, null));
    var paginationItem = screen.queryByRole('option', {
      name: 'Display additional results...'
    });
    expect(paginationItem).toBeInTheDocument();
  });
  it('renders a custom pagination label', function () {
    var paginationText = 'Show more...';
    render( /*#__PURE__*/React.createElement(Pagination, {
      paginationText: paginationText
    }));
    expect(screen.queryByRole('option', {
      name: paginationText
    })).toBeInTheDocument();
  });
  it('renders a custom pagination label component', function () {
    var paginationText = /*#__PURE__*/React.createElement("div", null, "Show more...");
    render( /*#__PURE__*/React.createElement(Pagination, {
      paginationText: paginationText
    }));
    var item = screen.queryByRole('option', {
      name: 'Show more...'
    });
    expect(item).toBeInTheDocument();
    expect(item).toHaveAttribute('aria-label', '');
  });
  it('does not show a paginator when there are no results', function () {
    render( /*#__PURE__*/React.createElement(Pagination, {
      options: []
    }));
    expect(screen.queryByRole('option', {
      name: 'Display additional results...'
    })).not.toBeInTheDocument();
  });
  it('renders custom menu item children', function () {
    render( /*#__PURE__*/React.createElement(CustomChildren, null));
    expect(screen.getAllByRole('option')[0]).toHaveTextContent('Population');
  });
});