import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import addCustomOption from './addCustomOption';
import options from '../tests/data';
describe('addCustomOption', function () {
  var defaultProps, labelKey;
  beforeEach(function () {
    labelKey = 'name';
    defaultProps = {
      allowNew: true,
      labelKey: labelKey,
      text: 'zzz'
    };
  });
  it('does not add a custom option when `allowNew` is false', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      allowNew: false
    });

    expect(addCustomOption(options, props)).toBe(false);
  });
  it('does not add a custom option when no text is entered', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      text: ''
    });

    expect(addCustomOption(options, props)).toBe(false);
  });
  it('adds a custom option if no matches are found', function () {
    expect(addCustomOption(options, defaultProps)).toBe(true);
  });
  it('adds a custom option when `labelKey` is a function', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      labelKey: function labelKey(o) {
        return o.name;
      }
    });

    expect(addCustomOption(options, props)).toBe(true);
  });
  it('adds a custom option when no exact matches are found', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      text: 'Ala'
    });

    expect(addCustomOption(options, props)).toBe(true);
  });
  it('does not add a custom option when an exact match is found', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      text: 'Wyoming'
    });

    expect(addCustomOption(options, props)).toBe(false);
  });
  it('adds a custom option when `allowNew` returns true', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      allowNew: function allowNew() {
        return true;
      },
      text: 'North Carolina' // Would otherwise return false

    });

    expect(addCustomOption(options, props)).toBe(true);
  });
  it('does not add a custom option when `allowNew` returns false', function () {
    var props = _objectSpread(_objectSpread({}, defaultProps), {}, {
      allowNew: function allowNew() {
        return false;
      },
      text: 'xxx' // Would otherwise return true

    });

    expect(addCustomOption(options, props)).toBe(false);
  });
});