import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import defaultSelectHint from './defaultSelectHint';
describe('defaultSelectHint', function () {
  var event, preventDefault;
  beforeEach(function () {
    preventDefault = jest.fn();
    event = {
      currentTarget: {
        value: 'Cali'
      },
      key: 'Tab',
      preventDefault: preventDefault
    };
  });
  it('returns true when tab is pressed', function () {
    expect(defaultSelectHint(event)).toBe(true);
    expect(preventDefault).toHaveBeenCalledTimes(1);
  });
  it('checks hinting behavior when the right arrow key is pressed', function () {
    event = _objectSpread(_objectSpread({}, event), {}, {
      key: 'ArrowRight'
    });
    event.currentTarget.selectionStart = 3;
    expect(defaultSelectHint(event)).toBe(false);
    event.currentTarget.selectionStart = 4;
    expect(defaultSelectHint(event)).toBe(true);
    event.currentTarget.selectionStart = null;
    expect(defaultSelectHint(event)).toBe(true);
  });
  it('returns false for other keys', function () {
    // Build up a set of valid keys.
    [].concat(['ArrowUp', 'ArrowRight', 'ArrowDown', 'ArrowLeft']).concat('0123456789'.split('')).concat('abcdefghijqlmnopqrstuvwxyz'.split('')) // Letter keys
    .concat(['Backspace', ' ', 'Escape', 'Enter', 'Tab']).concat(';=,-./`'.split('')).concat("[\\]'".split('')).filter(function (key) {
      return key !== 'Enter' && key !== 'ArrowRight' && key !== 'Tab';
    }).forEach(function (key) {
      event.key = key;
      expect(defaultSelectHint(event)).toBe(false);
    });
  });
  it('accepts a callback for custom behaviors', function () {
    event = _objectSpread(_objectSpread({}, event), {}, {
      key: 'Enter'
    });

    var selectHint = function selectHint(shouldSelectHint, e) {
      return e.key === 'Enter' || shouldSelectHint;
    };

    expect(defaultSelectHint(event, selectHint)).toBe(true);
  });
});