import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import getHintText from './getHintText';
import states from '../tests/data';
var props = {
  activeIndex: -1,
  activeItem: null,
  initialItem: {
    name: 'Alabama'
  },
  isFocused: true,
  isMenuShown: true,
  labelKey: 'name',
  minLength: 0,
  multiple: false,
  selected: [],
  text: 'alA'
};
describe('getHintText', function () {
  it('returns a case-sensitive hint string', function () {
    var hintText = getHintText(props);
    expect(hintText).toBe('alAbama');
  });
  it('returns an empty string when the text is empty', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      text: ''
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when the menu is not focused', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      isFocused: false
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when a menu item is active', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      activeIndex: 0
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when there is a selection', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      selected: [states[0]]
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when the menu is hidden', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      isMenuShown: false
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when the initial item does not begin with the ' + 'input string', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      text: 'Cal'
    }));
    expect(hintText).toBe('');
  });
  it('returns an empty string when the initial item is a custom option', function () {
    var initialItem = _objectSpread(_objectSpread({}, props.initialItem), {}, {
      customOption: true
    });

    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      initialItem: initialItem
    }));
    expect(hintText).toBe('');
  });
  it('handles string with composed diacritical marks', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      initialItem: 'Schön ist, was schön lässt.',
      text: 'schon is'
    }));
    expect(hintText).toBe('schon ist, was schön lässt.');
  });
  it('handles string with combined diacritical marks', function () {
    var hintText = getHintText(_objectSpread(_objectSpread({}, props), {}, {
      initialItem: "Scho\u0308n ist, was scho\u0308n la\u0308sst.",
      text: 'schon is'
    }));
    expect(hintText).toBe("schon ist, was scho\u0308n la\u0308sst.");
  });
});