/* eslint-disable import/no-extraneous-dependencies */
import range from "lodash/range";
import stripDiacritics from './stripDiacritics';
describe('stripDiacritics', function () {
  it('removes accents and other diacritical marks from a string', function () {
    var string = 'ÆÐƎƐŒẞæǝɛœſßĄƁÇĐƊĘĦĮƘŁØƠŞȘŢȚŦŲƯƳąɓçđɗęħįƙłøơşșţțŧųưƴÁÀÂÄǍĂĀÃÅǺĄÆǼǢƁĆĊĈČÇĎḌĐƊÐÉÈĖÊËĚĔĒĘẸƎƐĠĜǦĞĢáàâäǎăāãåǻąæǽǣɓćċĉčçďḍđɗéèėêëěĕēęẹġĝǧğģĤḤĦIÍÌİÎÏǏĬĪĨĮỊĴĶƘĹĻŁĽĿNŃŇÑŅÓÒÔÖǑŎŌÕŐỌØǾƠŒĥḥħıíìiîïǐĭīĩįịĵķƙĸĺļłľŀŉńňñņóòôöǒŏōõőọøǿơœŔŘŖŚŜŠŞȘṢẞŤŢṬŦÚÙÛÜǓŬŪŨŰŮŲỤƯẂẀŴẄÝỲŶŸȲỸƳŹŻŽẒŕřŗſśŝšşșṣßťţṭŧúùûüǔŭūũűůųụưẃẁŵẅýỳŷÿȳỹƴźżžẓ';
    var result = 'AEDEEOESaeeeoelsABCDDEHIKLOOSSTTTUUYabcddehikloosstttuuyAAAAAAAAAAAAEAEAEBCCCCCDDDDDEEEEEEEEEEEEGGGGGaaaaaaaaaaaaeaeaebcccccddddeeeeeeeeeegggggHHHIIIIIIIIIIIIJKKLLLLLNNNNNOOOOOOOOOOOOOOEhhhiiiiiiiiiiiijkkĸlllllnnnnnooooooooooooooeRRRSSSSSSSTTTTUUUUUUUUUUUUUWWWWYYYYYYYZZZZrrrlsssssssttttuuuuuuuuuuuuuwwwwyyyyyyyzzzz';
    expect(stripDiacritics(string)).toBe(result);
  });
  it('works for non-latin alphabets', function () {
    var string = 'ΆΈΉΊΪΌΎΫΏάέίϊΐόύϋΰ';
    var result = 'ΑΕΗΙΙΟΥΥΩαειιιουυυ';
    expect(stripDiacritics(string)).toBe(result);
  });
  it('removes combining diacritical marks from a string', function () {
    var alphaRange = ['a', 'b', 'c', 'd', 'e', 'f'];
    var numRange = range(30, 37);
    var arr = [];
    numRange.forEach(function (n) {
      alphaRange.forEach(function (a) {
        arr.push(n + a);
      });
    }); // Build up a string of every unicode combining mark (\u0300-\u036F).

    var str = arr.concat(range(300, 370)).map(function (n) {
      return String.fromCharCode("0x0".concat(n));
    }).join('');
    expect(str.length).toBe(112);
    expect(stripDiacritics(str)).toBe('');
  });
});