import PropTypes from 'prop-types';
import React from 'react';
import Highlighter from '../Highlighter';
import Menu from '../Menu';
import MenuItem from '../MenuItem';
import { getOptionLabel, getOptionProperty, isString } from '../../utils';
const propTypes = {
    newSelectionPrefix: PropTypes.node,
    paginationText: PropTypes.node,
    renderMenuItemChildren: PropTypes.func,
};
const defaultProps = {
    newSelectionPrefix: 'New selection: ',
    paginationText: 'Display additional results...',
    renderMenuItemChildren: (option, props) => (React.createElement(Highlighter, { search: props.text }, getOptionLabel(option, props.labelKey))),
};
const TypeaheadMenu = (props) => {
    const { labelKey, newSelectionPrefix, options, paginationText, renderMenuItemChildren, ...menuProps } = props;
    const renderMenuItem = (option, position) => {
        const label = getOptionLabel(option, labelKey);
        const menuItemProps = {
            disabled: !!getOptionProperty(option, 'disabled'),
            label,
            option,
            position,
        };
        if (getOptionProperty(option, 'customOption')) {
            return (React.createElement(MenuItem, { ...menuItemProps, className: "rbt-menu-custom-option", key: position, label: label },
                newSelectionPrefix,
                React.createElement(Highlighter, { search: menuProps.text }, label)));
        }
        if (getOptionProperty(option, 'paginationOption')) {
            return (React.createElement(React.Fragment, { key: "pagination-option-divider" },
                React.createElement(Menu.Divider, null),
                React.createElement(MenuItem, { ...menuItemProps, className: "rbt-menu-pagination-option", label: isString(paginationText) ? paginationText : '' }, paginationText)));
        }
        return (React.createElement(MenuItem, { ...menuItemProps, key: position }, renderMenuItemChildren(option, props, position)));
    };
    return React.createElement(Menu, { ...menuProps }, options.map(renderMenuItem));
};
TypeaheadMenu.propTypes = propTypes;
TypeaheadMenu.defaultProps = defaultProps;
export default TypeaheadMenu;
